@@ -5,4 +5,4 @@ def jpeg_minify(jpeg, settings: dict):
     """Minify JPEG main function."""
     # TODO: Implement this
     # print(f"JPEG WAS CALLED FOR {len(jpeg)}!!!!! #############################################")
-    return jpeg
+    return jpeg, None
