@@ -9,4 +9,4 @@ def png_minify(png, settings: dict):
     #    pngquant.config()
     #    png=quant_data(self, data=None, dst=None, ndeep=None, ndigits=None, delete=True):
     # TODO: Implement this
-    return png
+    return png, None
