@@ -15,9 +15,14 @@ except Exception:
     logger.warning("NOTE: To install sass, please remember to use  use pip install libsass instead of pip install sass")
 
 
-def sass_minify(css, settings: dict):
+def sass_minify(scss, settings: dict):
     """Minify SASS main function."""
     if have_sass:
-        css = sass.compile(string=css)
-    css = css_minify(css=css, settings=settings)
-    return css
+        try:
+            css = sass.compile(string=scss)
+        except sass.CompileError as ce:
+            return (None, [f"SASS {ce}"])
+        except Exception as e:
+            return (None, [f"Error: Could not process SASS {e}"])
+    css, css_errors = css_minify(css=css, settings=settings)
+    return css, css_errors
